rm(list=ls())
# setwd("/Users/varun/Google\ Drive/PhD/2YP/Data/data_analysis")



# This section of the code installs all the missing packages --------------


list.of.packages <- c("haven", "stargazer", "readstata13","readr"
                      ,"plyr","dplyr","ggplot2","gghighlight","plm")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)


# Load packages Necessary for Analysis  -----------------------------------



library(haven)
library(stargazer)
library(readstata13)
library(readr)
library(plyr)
library(dplyr)
library(ggplot2)
library(gghighlight)
library(plm)



# Andhra ------------------------------------------------------------------

andhra <- read_csv("AE.Andhra_Pradesh.2018-05-08.csv")
colnames(andhra) <- tolower(colnames(andhra)) #Make lowercase
andhra_winners <- filter(andhra, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
andhra_winners$sex <- revalue(andhra_winners$sex, c("M"="0", "F"="1"))
andhra_winners$st_code <- rep("ANP", nrow(andhra_winners))
andhra_winners$state_year <- paste(andhra_winners$st_code,andhra_winners$year)
andhra_winners <-  andhra_winners %>% select(1,2,4,6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28) #subset data.

#Creating reservation dummies
andhra_winners$reservation <- NA
andhra_winners$reservation[andhra_winners$year > 1991] <- 1
andhra_winners$reservation[is.na(andhra_winners$reservation)] <- 0


#Creating 1/2 dummy
andhra_winners$fiftypercent <- NA
andhra_winners$fiftypercent[andhra_winners$year > 1991] <- 1/3
andhra_winners$fiftypercent[is.na(andhra_winners$fiftypercent)] <- 0



# Assam -------------------------------------------------------------------

assam <- read_csv("AE.Assam.2018-05-08.csv")
colnames(assam) <- tolower(colnames(assam)) #Make lowercase
assam_winners <- filter(assam, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
assam_winners$sex <- revalue(assam_winners$sex, c("M"="0", "F"="1"))
assam_winners$st_code <- rep("ASS", nrow(assam_winners))
assam_winners$state_year <- paste(assam_winners$st_code,assam_winners$year)
assam_winners <-  assam_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28) #subset data. # Dropped month, assembl number, delimid, constituency number and pollnumber and enop

#Creating reservation dummies
assam_winners$reservation <- NA
assam_winners$reservation[assam_winners$year > 2001] <- 1
assam_winners$reservation[is.na(assam_winners$reservation)] <- 0

#Creating 1/2 dummy
assam_winners$fiftypercent <- NA
assam_winners$fiftypercent[assam_winners$year > 2001] <- 1/3
assam_winners$fiftypercent[assam_winners$year > 2012] <- 1/2

assam_winners$fiftypercent[is.na(assam_winners$fiftypercent)] <- 0


# Bihar -------------------------------------------------------------------

bihar <- read_csv("AE.Bihar.2018-05-08.csv")
colnames(bihar) <- tolower(colnames(bihar)) #Make lowercase
bihar_winners <- filter(bihar, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
bihar_winners$sex <- revalue(bihar_winners$sex, c("M"="0", "F"="1"))
bihar_winners$st_code <- rep("BIH", nrow(bihar_winners))
bihar_winners$state_year <- paste(bihar_winners$st_code,bihar_winners$year)
bihar_winners <-  bihar_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28) 


#Creating reservation dummies
bihar_winners$reservation <- NA
bihar_winners$reservation[bihar_winners$year > 2001] <- 1
bihar_winners$reservation[is.na(bihar_winners$reservation)] <- 0

#Creating 1/2 dummy

bihar_winners$fiftypercent <- NA
bihar_winners$fiftypercent[bihar_winners$year > 2001] <- 1/3
bihar_winners$fiftypercent[bihar_winners$year > 2006] <- 1/2
bihar_winners$fiftypercent[is.na(bihar_winners$fiftypercent)] <- 0

# Gujarat -----------------------------------------------------------------

gujarat <- read_csv("AE.Gujarat.2018-07-23.csv") #read_csv("AE.Gujarat.2018-05-08.csv")
colnames(gujarat) <- tolower(colnames(gujarat)) #Make lowercase
gujarat_winners <- filter(gujarat, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
gujarat_winners <- gujarat_winners %>% select(-c(27))
gujarat_winners$sex <- revalue(gujarat_winners$sex, c("M"="0", "F"="1"))
gujarat_winners$st_code <- rep("GUJ", nrow(gujarat_winners))
gujarat_winners$state_year <- paste(gujarat_winners$st_code,gujarat_winners$year)
gujarat_winners <-  gujarat_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28) 

#Creating reservation dummies
gujarat_winners$reservation <- NA
gujarat_winners$reservation[gujarat_winners$year > 1995] <- 1
gujarat_winners$reservation[is.na(gujarat_winners$reservation)] <- 0


#Creating 1/2 dummy
gujarat_winners$fiftypercent <- NA
gujarat_winners$fiftypercent[gujarat_winners$year > 1995] <- 1/3
gujarat_winners$fiftypercent[gujarat_winners$year > 2009] <- 1/2
gujarat_winners$fiftypercent[is.na(gujarat_winners$fiftypercent)] <- 0

# Haryana -----------------------------------------------------------------
haryana <- read_csv("AE.Haryana.2018-05-08.csv")
colnames(haryana) <- tolower(colnames(haryana)) #Make lowercase
haryana_winners <- filter(haryana, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
haryana_winners <- haryana_winners %>% select(-c(27))

haryana_winners$sex <- revalue(haryana_winners$sex, c("M"="0", "F"="1"))
haryana_winners$st_code <- rep("HAR", nrow(haryana_winners))
haryana_winners$state_year <- paste(haryana_winners$st_code,haryana_winners$year)
haryana_winners <-  haryana_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28) 

#Creating reservation dummies
haryana_winners$reservation <- NA
haryana_winners$reservation[haryana_winners$year > 1995] <- 1
haryana_winners$reservation[is.na(haryana_winners$reservation)] <- 0

#Creating 1/2 dummy
haryana_winners$fiftypercent <- NA
haryana_winners$fiftypercent[haryana_winners$year > 1995] <- 1/3
haryana_winners$fiftypercent[is.na(haryana_winners$fiftypercent)] <- 0


# Himachal ----------------------------------------------------------------
himachal <- read_csv("AE.Himachal_Pradesh.2018-07-23.csv")  #read_csv("AE.Himachal_Pradesh.2018-05-08.csv")
colnames(himachal) <- tolower(colnames(himachal)) #Make lowercase
himachal_winners <- filter(himachal, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
himachal_winners <- himachal_winners %>% select(-c(27))

himachal_winners$sex <- revalue(himachal_winners$sex, c("M"="0", "F"="1"))
himachal_winners$st_code <- rep("HIP", nrow(himachal_winners))
himachal_winners$state_year <- paste(himachal_winners$st_code,himachal_winners$year)
himachal_winners <-  himachal_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28) 

#Creating reservation dummies
himachal_winners$reservation <- NA
himachal_winners$reservation[himachal_winners$year > 1995] <- 1
himachal_winners$reservation[is.na(himachal_winners$reservation)] <- 0

#Creating 1/2 dummy
himachal_winners$fiftypercent <- NA
himachal_winners$fiftypercent[himachal_winners$year > 1995] <- 1/3
himachal_winners$fiftypercent[himachal_winners$year > 2008] <- 1/2
himachal_winners$fiftypercent[is.na(himachal_winners$fiftypercent)] <- 0

# J&K ---------------------------------------------------------------


jandk <- read_csv("AE.Jammu_&_Kashmir.2018-05-08.csv")
colnames(jandk) <- tolower(colnames(jandk)) #Make lowercase
jandk_winners <- filter(jandk, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
jandk_winners$sex <- revalue(jandk_winners$sex, c("M"="0", "F"="1"))
jandk_winners$st_code <- rep("JAK", nrow(jandk_winners))
jandk_winners$state_year <- paste(jandk_winners$st_code,jandk_winners$year)
jandk_winners <-  jandk_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28) 

#Creating reservation dummies
jandk_winners$reservation <- NA
jandk_winners$reservation[is.na(jandk_winners$reservation)] <- 0

#Creating 1/2 dummy
jandk_winners$fiftypercent <- NA
jandk_winners$fiftypercent[is.na(jandk_winners$fiftypercent)] <- 0

# Karnataka ---------------------------------------------------------------
karnataka <- read_csv("AE.Karnataka.2018-05-08.csv")
colnames(karnataka) <- tolower(colnames(karnataka)) #Make lowercase
karnataka_winners <- filter(karnataka, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
karnataka_winners <- karnataka_winners %>% select(-c(27))

karnataka_winners$sex <- revalue(karnataka_winners$sex, c("M"="0", "F"="1"))
karnataka_winners$st_code <- rep("KAR", nrow(karnataka_winners))
karnataka_winners$state_year <- paste(karnataka_winners$st_code,karnataka_winners$year)
karnataka_winners <-  karnataka_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
karnataka_winners$reservation <- NA
karnataka_winners$reservation[karnataka_winners$year > 1987] <- 1
karnataka_winners$reservation[is.na(karnataka_winners$reservation)] <- 0

#Creating 1/2 dummy
karnataka_winners$fiftypercent <- NA
karnataka_winners$fiftypercent[karnataka_winners$year > 1993] <- 1/3
karnataka_winners$fiftypercent[karnataka_winners$year > 2010] <- 1/2
karnataka_winners$fiftypercent[is.na(karnataka_winners$fiftypercent)] <- 0


# Kerala ------------------------------------------------------------------
kerala <- read_csv("AE.Kerala.2018-05-08.csv")
colnames(kerala) <- tolower(colnames(kerala)) #Make lowercase
kerala_winners <- filter(kerala, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
kerala_winners$sex <- revalue(kerala_winners$sex, c("M"="0", "F"="1"))
kerala_winners$st_code <- rep("KER", nrow(kerala_winners))
kerala_winners$state_year <- paste(kerala_winners$st_code,kerala_winners$year)
kerala_winners <-  kerala_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
kerala_winners$reservation <- NA
kerala_winners$reservation[kerala_winners$year > 1995] <- 1
kerala_winners$reservation[is.na(kerala_winners$reservation)] <- 0

#Creating 1/2 dummy
kerala_winners$fiftypercent <- NA
kerala_winners$fiftypercent[kerala_winners$year > 1995] <- 1/3
kerala_winners$fiftypercent[kerala_winners$year > 2009] <- 1/2
kerala_winners$fiftypercent[is.na(kerala_winners$fiftypercent)] <- 0

# Madhya Pradesh ----------------------------------------------------------
madhya_pradesh <- read_csv("AE.Madhya_Pradesh.2018-05-08.csv")
colnames(madhya_pradesh) <- tolower(colnames(madhya_pradesh)) #Make lowercase
madhya_pradesh_winners <- filter(madhya_pradesh, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
madhya_pradesh_winners <- madhya_pradesh_winners %>% select(-c(27))

madhya_pradesh_winners$sex <- revalue(madhya_pradesh_winners$sex, c("M"="0", "F"="1"))
madhya_pradesh_winners$st_code <- rep("MAP", nrow(madhya_pradesh_winners))
madhya_pradesh_winners$state_year <- paste(madhya_pradesh_winners$st_code,madhya_pradesh_winners$year)
madhya_pradesh_winners <-  madhya_pradesh_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
madhya_pradesh_winners$reservation <- NA
madhya_pradesh_winners$reservation[madhya_pradesh_winners$year > 1994] <- 1
madhya_pradesh_winners$reservation[is.na(madhya_pradesh_winners$reservation)] <- 0


#Creating 1/2 dummy
madhya_pradesh_winners$fiftypercent <- NA
madhya_pradesh_winners$fiftypercent[madhya_pradesh_winners$year > 1994] <- 1/3
madhya_pradesh_winners$fiftypercent[madhya_pradesh_winners$year > 2011] <- 1/2
madhya_pradesh_winners$fiftypercent[is.na(madhya_pradesh_winners$fiftypercent)] <- 0



# maharashtra -------------------------------------------------------------
maharashtra <- read_csv("AE.maharashtra.2018-05-08.csv")
colnames(maharashtra) <- tolower(colnames(maharashtra)) #Make lowercase
maharashtra_winners <- filter(maharashtra, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
maharashtra_winners$sex <- revalue(maharashtra_winners$sex, c("M"="0", "F"="1"))
maharashtra_winners$st_code <- rep("MAH", nrow(maharashtra_winners))
maharashtra_winners$state_year <- paste(maharashtra_winners$st_code,maharashtra_winners$year)
maharashtra_winners <-  maharashtra_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
maharashtra_winners$reservation <- NA
maharashtra_winners$reservation[maharashtra_winners$year > 1997] <- 1
maharashtra_winners$reservation[is.na(maharashtra_winners$reservation)] <- 0

#Creating 1/2 dummy
maharashtra_winners$fiftypercent <- NA
maharashtra_winners$fiftypercent[maharashtra_winners$year > 1997] <- 1/3
maharashtra_winners$fiftypercent[maharashtra_winners$year > 2011] <- 1/2
maharashtra_winners$fiftypercent[is.na(maharashtra_winners$fiftypercent)] <- 0


# Manipur -----------------------------------------------------------------
manipur <- read_csv("AE.Manipur.2018-05-08.csv") #read_csv("AE.Manipur.2018-05-08.csv")
colnames(manipur) <- tolower(colnames(manipur)) #Make lowercase
manipur_winners <- filter(manipur, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
manipur_winners$sex <- revalue(manipur_winners$sex, c("M"="0", "F"="1"))
manipur_winners$st_code <- rep("MAN", nrow(manipur_winners))
manipur_winners$state_year <- paste(manipur_winners$st_code,manipur_winners$year)
manipur_winners <-  manipur_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
manipur_winners$reservation <- NA
manipur_winners$reservation[manipur_winners$year > 1997] <- 1
manipur_winners$reservation[is.na(manipur_winners$reservation)] <- 0

#Creating 1/2 dummy
manipur_winners$fiftypercent <- NA
manipur_winners$fiftypercent[manipur_winners$year > 1997] <- 1/3
manipur_winners$fiftypercent[is.na(manipur_winners$fiftypercent)] <- 0

# Meghalaya ---------------------------------------------------------------
meghalaya <- read_csv("AE.Meghalaya.2018-05-08.csv")
colnames(meghalaya) <- tolower(colnames(meghalaya)) #Make lowercase
meghalaya_winners <- filter(meghalaya, position ==1, poll_no==0, year!=2018) #Filter out the winners # Just take poll 0
meghalaya_winners <- meghalaya_winners %>% select(-c(27))

meghalaya_winners$sex <- revalue(meghalaya_winners$sex, c("M"="0", "F"="1"))
meghalaya_winners$st_code <- rep("MEG", nrow(meghalaya_winners))
meghalaya_winners$state_year <- paste(meghalaya_winners$st_code,meghalaya_winners$year)
meghalaya_winners <-  meghalaya_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
meghalaya_winners$reservation <- NA
meghalaya_winners$reservation[is.na(meghalaya_winners$reservation)] <- 0

#Creating 1/2 dummy
meghalaya_winners$fiftypercent <- NA
meghalaya_winners$fiftypercent[is.na(meghalaya_winners$fiftypercent)] <- 0

# Nagaland ----------------------------------------------------------------
nagaland <- read_csv("AE.nagaland.2018-05-08.csv")
colnames(nagaland) <- tolower(colnames(nagaland)) #Make lowercase
nagaland_winners <- filter(nagaland, position ==1, poll_no==0, year!=2018) #Filter out the winners # Just take poll 0
nagaland_winners <- nagaland_winners %>% select(-c(27))

nagaland_winners$sex <- revalue(nagaland_winners$sex, c("M"="0", "F"="1"))
nagaland_winners$st_code <- rep("NAG", nrow(nagaland_winners))
nagaland_winners$state_year <- paste(nagaland_winners$st_code,nagaland_winners$year)
nagaland_winners <-  nagaland_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
nagaland_winners$reservation <- NA
nagaland_winners$reservation[is.na(nagaland_winners$reservation)] <- 0

#Creating 1/2 dummy
nagaland_winners$fiftypercent <- NA
nagaland_winners$fiftypercent[is.na(nagaland_winners$fiftypercent)] <- 0


# Odisha ------------------------------------------------------------------
odisha <- read_csv("AE.Odisha.2018-05-08.csv")
colnames(odisha) <- tolower(colnames(odisha)) #Make lowercase
odisha_winners <- filter(odisha, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
odisha_winners$sex <- revalue(odisha_winners$sex, c("M"="0", "F"="1"))
odisha_winners$st_code <- rep("ORI", nrow(odisha_winners))
odisha_winners$state_year <- paste(odisha_winners$st_code,odisha_winners$year)
odisha_winners <-  odisha_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
odisha_winners$reservation <- NA
odisha_winners$reservation[odisha_winners$year > 1997] <- 1
odisha_winners$reservation[is.na(odisha_winners$reservation)] <- 0

#Creating 1/2 dummy
odisha_winners$fiftypercent <- NA
odisha_winners$fiftypercent[odisha_winners$year > 1997] <- 1/3
odisha_winners$fiftypercent[odisha_winners$year > 2011] <- 1/2
odisha_winners$fiftypercent[is.na(odisha_winners$fiftypercent)] <- 0

# Punjab ------------------------------------------------------------------

punjab <- read_csv("AE.Punjab.2018-05-08.csv")  #read_csv("AE.Punjab.2018-05-08.csv")
colnames(punjab) <- tolower(colnames(punjab)) #Make lowercase
punjab_winners <- filter(punjab, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
punjab_winners <- punjab_winners %>% select(-c(27))


punjab_winners$sex <- revalue(punjab_winners$sex, c("M"="0", "F"="1"))
punjab_winners$st_code <- rep("PUN", nrow(punjab_winners))
punjab_winners$state_year <- paste(punjab_winners$st_code,punjab_winners$year)
punjab_winners <-  punjab_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
punjab_winners$reservation <- NA
punjab_winners$reservation[punjab_winners$year > 1998] <- 1
punjab_winners$reservation[is.na(punjab_winners$reservation)] <- 0

#Creating 1/2 dummy
punjab_winners$fiftypercent <- NA
punjab_winners$fiftypercent[punjab_winners$year > 1998] <- 1/3
punjab_winners$fiftypercent[punjab_winners$year > 2017] <- 1/2
punjab_winners$fiftypercent[is.na(punjab_winners$fiftypercent)] <- 0


# Rajasthan ---------------------------------------------------------------
rajasthan <- read_csv("AE.Rajasthan.2018-05-08.csv")
colnames(rajasthan) <- tolower(colnames(rajasthan)) #Make lowercase
rajasthan_winners <- filter(rajasthan, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
rajasthan_winners <- rajasthan_winners %>% select(-c(27))


rajasthan_winners$sex <- revalue(rajasthan_winners$sex, c("M"="0", "F"="1"))
rajasthan_winners$st_code <- rep("RAJ", nrow(rajasthan_winners))
rajasthan_winners$state_year <- paste(rajasthan_winners$st_code,rajasthan_winners$year)
rajasthan_winners <-  rajasthan_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
rajasthan_winners$reservation <- NA
rajasthan_winners$reservation[rajasthan_winners$year > 1995] <- 1
rajasthan_winners$reservation[is.na(rajasthan_winners$reservation)] <- 0

#Creating 1/2 dummy
rajasthan_winners$fiftypercent <- NA
rajasthan_winners$fiftypercent[rajasthan_winners$year > 1995] <- 1/3
rajasthan_winners$fiftypercent[rajasthan_winners$year > 2008] <- 1/2
rajasthan_winners$fiftypercent[is.na(rajasthan_winners$fiftypercent)] <- 0


# Sikkim ------------------------------------------------------------------
sikkim <- read_csv("AE.Sikkim.2018-05-08.csv")
colnames(sikkim) <- tolower(colnames(sikkim)) #Make lowercase
sikkim_winners <- filter(sikkim, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
sikkim_winners$sex <- revalue(sikkim_winners$sex, c("M"="0", "F"="1"))
sikkim_winners$st_code <- rep("SIK", nrow(sikkim_winners))
sikkim_winners$state_year <- paste(sikkim_winners$st_code,sikkim_winners$year)
sikkim_winners <-  sikkim_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)


#Creating reservation dummies
sikkim_winners$reservation <- NA
sikkim_winners$reservation[sikkim_winners$year > 1997] <- 1
sikkim_winners$reservation[is.na(sikkim_winners$reservation)] <- 0

#Creating 1/2 dummy
sikkim_winners$fiftypercent <- NA
sikkim_winners$fiftypercent[sikkim_winners$year > 1997] <- 1/3
sikkim_winners$fiftypercent[sikkim_winners$year > 2011] <- 1/2
sikkim_winners$fiftypercent[is.na(sikkim_winners$fiftypercent)] <- 0


# Tamil Nadu --------------------------------------------------------------
tamil_nadu <- read_csv("AE.Tamil_Nadu.2018-05-08.csv")
colnames(tamil_nadu) <- tolower(colnames(tamil_nadu)) #Make lowercase
tamil_nadu_winners <- filter(tamil_nadu, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
tamil_nadu_winners$sex <- revalue(tamil_nadu_winners$sex, c("M"="0", "F"="1"))
tamil_nadu_winners$st_code <- rep("TAM", nrow(tamil_nadu_winners))
tamil_nadu_winners$state_year <- paste(tamil_nadu_winners$st_code,tamil_nadu_winners$year)
tamil_nadu_winners <-  tamil_nadu_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
tamil_nadu_winners$reservation <- NA
tamil_nadu_winners$reservation[tamil_nadu_winners$year > 1996] <- 1
tamil_nadu_winners$reservation[is.na(tamil_nadu_winners$reservation)] <- 0


#Creating 1/2 dummy
tamil_nadu_winners$fiftypercent <- NA
tamil_nadu_winners$fiftypercent[tamil_nadu_winners$year > 1996] <- 1/3
tamil_nadu_winners$fiftypercent[tamil_nadu_winners$year > 2016] <- 1/2
tamil_nadu_winners$fiftypercent[is.na(tamil_nadu_winners$fiftypercent)] <- 0



# tripura -----------------------------------------------------------------

tripura <- read_csv("AE.Tripura.2018-05-08.csv")
colnames(tripura) <- tolower(colnames(tripura)) #Make lowercase
tripura_winners <- filter(tripura, position ==1, poll_no==0, year!=2018) #Filter out the winners # Just take poll 0
tripura_winners <- tripura_winners %>% select(-c(27))


tripura_winners$sex <- revalue(tripura_winners$sex, c("M"="0", "F"="1"))
tripura_winners$st_code <- rep("TRI", nrow(tripura_winners))
tripura_winners$state_year <- paste(tripura_winners$st_code,tripura_winners$year)
tripura_winners <-  tripura_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
tripura_winners$reservation <- NA
tripura_winners$reservation[tripura_winners$year > 1994] <- 1
tripura_winners$reservation[is.na(tripura_winners$reservation)] <- 0

#Creating 1/2 dummy
tripura_winners$fiftypercent <- NA
tripura_winners$fiftypercent[tripura_winners$year > 1996] <- 1/3
tripura_winners$fiftypercent[is.na(tripura_winners$fiftypercent)] <- 0


# Uttar Pradesh -----------------------------------------------------------

uttar_pradesh <- read_csv("AE.Uttar_Pradesh.2018-07-23.csv") #read_csv("AE.Uttar_Pradesh.2018-05-08.csv")
colnames(uttar_pradesh) <- tolower(colnames(uttar_pradesh)) #Make lowercase
uttar_pradesh_winners <- filter(uttar_pradesh, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
uttar_pradesh_winners <- uttar_pradesh_winners %>% select(-c(27))


uttar_pradesh_winners$sex <- revalue(uttar_pradesh_winners$sex, c("M"="0", "F"="1"))
uttar_pradesh_winners$st_code <- rep("UTP", nrow(uttar_pradesh_winners))
uttar_pradesh_winners$state_year <- paste(uttar_pradesh_winners$st_code,uttar_pradesh_winners$year)
uttar_pradesh_winners <-  uttar_pradesh_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
uttar_pradesh_winners$reservation <- NA
uttar_pradesh_winners$reservation[uttar_pradesh_winners$year > 1995] <- 1
uttar_pradesh_winners$reservation[is.na(uttar_pradesh_winners$reservation)] <- 0

#Creating 1/2 dummy
uttar_pradesh_winners$fiftypercent <- NA
uttar_pradesh_winners$fiftypercent[uttar_pradesh_winners$year > 1995] <- 1/3
uttar_pradesh_winners$fiftypercent[uttar_pradesh_winners$year > 2008] <- 1/2
uttar_pradesh_winners$fiftypercent[is.na(uttar_pradesh_winners$fiftypercent)] <- 0

# West Bengal -------------------------------------------------------------

west_bengal <- read_csv("AE.West_Bengal.2018-05-08.csv")
colnames(west_bengal) <- tolower(colnames(west_bengal)) #Make lowercase
west_bengal_winners <- filter(west_bengal, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
west_bengal_winners$sex <- revalue(west_bengal_winners$sex, c("M"="0", "F"="1"))
west_bengal_winners$st_code <- rep("WEB", nrow(west_bengal_winners))
west_bengal_winners$state_year <- paste(west_bengal_winners$st_code,west_bengal_winners$year)
west_bengal_winners <-  west_bengal_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
west_bengal_winners$reservation <- NA
west_bengal_winners$reservation[west_bengal_winners$year > 1993] <- 1
west_bengal_winners$reservation[is.na(west_bengal_winners$reservation)] <- 0

#Creating 1/2 dummy
west_bengal_winners$fiftypercent <- NA
west_bengal_winners$fiftypercent[west_bengal_winners$year > 1993] <- 1/3
west_bengal_winners$fiftypercent[west_bengal_winners$year > 2012] <- 1/2
west_bengal_winners$fiftypercent[is.na(west_bengal_winners$fiftypercent)] <- 0

# Arunachal ---------------------------------------------------------------

arunachal <- read_csv("AE.Arunachal_Pradesh.2018-05-08.csv")
colnames(arunachal) <- tolower(colnames(arunachal)) #Make lowercase
arunachal_winners <- filter(arunachal, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
arunachal_winners$sex <- revalue(arunachal_winners$sex, c("M"="0", "F"="1"))
arunachal_winners$st_code <- rep("ARP", nrow(arunachal_winners))
arunachal_winners$state_year <- paste(arunachal_winners$st_code,arunachal_winners$year)
arunachal_winners <-  arunachal_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
arunachal_winners$reservation <- NA
arunachal_winners$reservation[arunachal_winners$year > 2003] <- 1
arunachal_winners$reservation[is.na(arunachal_winners$reservation)] <- 0

#Creating 1/2 dummy
arunachal_winners$fiftypercent <- NA
arunachal_winners$fiftypercent[arunachal_winners$year > 2003] <- 1/3
arunachal_winners$fiftypercent[is.na(arunachal_winners$fiftypercent)] <- 0

# Delhi -------------------------------------------------------------------
delhi <- read_csv("AE.Delhi.2018-05-08.csv")
colnames(delhi) <- tolower(colnames(delhi)) #Make lowercase
delhi_winners <- filter(delhi, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
delhi_winners$sex <- revalue(delhi_winners$sex, c("M"="0", "F"="1"))
delhi_winners$st_code <- rep("DEL", nrow(delhi_winners))
delhi_winners$state_year <- paste(delhi_winners$st_code,delhi_winners$year)
delhi_winners <-  delhi_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
delhi_winners$reservation <- NA
delhi_winners$reservation[delhi_winners$year > 2007] <- 1
delhi_winners$reservation[is.na(delhi_winners$reservation)] <- 0

#Creating 1/2 dummy
delhi_winners$fiftypercent <- NA
delhi_winners$fiftypercent[delhi_winners$year > 2007] <- 1/3
delhi_winners$fiftypercent[delhi_winners$year > 2012] <- 1/2
delhi_winners$fiftypercent[is.na(delhi_winners$fiftypercent)] <- 0

# Goa ---------------------------------------------------------------------
goa <- read_csv("AE.Goa.2018-07-23.csv") #read_csv("AE.Goa.2018-05-08.csv")
colnames(goa) <- tolower(colnames(goa)) #Make lowercase
goa_winners <- filter(goa, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
goa_winners$sex <- revalue(goa_winners$sex, c("M"="0", "F"="1"))
goa_winners$st_code <- rep("GOA", nrow(goa_winners))
goa_winners$state_year <- paste(goa_winners$st_code,goa_winners$year)
goa_winners <-  goa_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
goa_winners$reservation <- NA
goa_winners$reservation[goa_winners$year > 2000] <- 1
goa_winners$reservation[is.na(goa_winners$reservation)] <- 0

#Creating 1/2 dummy
goa_winners$fiftypercent <- NA
goa_winners$fiftypercent[goa_winners$year > 2000] <- 1/3
goa_winners$fiftypercent[is.na(goa_winners$fiftypercent)] <- 0

# Mizoram -----------------------------------------------------------------

mizoram <- read_csv("AE.Mizoram.2018-05-08.csv")
colnames(mizoram) <- tolower(colnames(mizoram)) #Make lowercase
mizoram_winners <- filter(mizoram, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
mizoram_winners$sex <- revalue(mizoram_winners$sex, c("M"="0", "F"="1"))
mizoram_winners$st_code <- rep("MIZ", nrow(mizoram_winners))
mizoram_winners$state_year <- paste(mizoram_winners$st_code,mizoram_winners$year)
mizoram_winners <-  mizoram_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
mizoram_winners$reservation <- NA
mizoram_winners$reservation[is.na(mizoram_winners$reservation)] <- 0

#Creating 1/2 dummies
mizoram_winners$fiftypercent <- NA
mizoram_winners$fiftypercent[is.na(mizoram_winners$fiftypercent)] <- 0

# Puducherry --------------------------------------------------------------

puducherry <- read_csv("AE.Puducherry.2018-05-08.csv")
colnames(puducherry) <- tolower(colnames(puducherry)) #Make lowercase
puducherry_winners <- filter(puducherry, position ==1, poll_no==0) #Filter out the winners # Just take poll 0


puducherry_winners$sex <- revalue(puducherry_winners$sex, c("M"="0", "F"="1"))
puducherry_winners$st_code <- rep("PUD", nrow(puducherry_winners))
puducherry_winners$state_year <- paste(puducherry_winners$st_code,puducherry_winners$year)
puducherry_winners <-  puducherry_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)

#Creating reservation dummies
puducherry_winners$reservation <- NA
puducherry_winners$reservation[is.na(puducherry_winners$reservation)] <- 0

#Creating 1/2 dummies
puducherry_winners$fiftypercent <- NA
puducherry_winners$fiftypercent[is.na(puducherry_winners$fiftypercent)] <- 0



# # Jharkhand ---------------------------------------------------------------
# 
# jharkhand <- read_csv("AE.Jharkhand.2018-05-08.csv")
# colnames(jharkhand) <- tolower(colnames(jharkhand)) #Make lowercase
# jharkhand_winners <- filter(jharkhand, position ==1, poll_no==0,year!=2017) #Filter out the winners # Just take poll 0
# jharkhand_winners <- jharkhand_winners %>% select(-c(27))
# 
# 
# jharkhand_winners$sex <- revalue(jharkhand_winners$sex, c("M"="0", "F"="1"))
# jharkhand_winners$st_code <- rep("JHAR", nrow(jharkhand_winners))
# jharkhand_winners$state_year <- paste(jharkhand_winners$st_code,jharkhand_winners$year)
# jharkhand_winners <-  jharkhand_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)
# 
# #Creating reservation dummies
# jharkhand_winners$reservation <- NA
# jharkhand_winners$reservation[jharkhand_winners$year > 2010] <- 1
# jharkhand_winners$reservation[is.na(jharkhand_winners$reservation)] <- 0
# 
# #Creating 1/2 dummy
# jharkhand_winners$fiftypercent <- NA
# jharkhand_winners$fiftypercent[jharkhand_winners$year > 2010] <- 1/2
# jharkhand_winners$fiftypercent[is.na(jharkhand_winners$fiftypercent)] <- 0
# 
# 
# 
# # Chattisgarh -------------------------------------------------------------
# 
# chattisgarh <- read_csv("AE.Chhattisgarh.2018-05-08.csv")
# colnames(chattisgarh) <- tolower(colnames(chattisgarh)) #Make lowercase
# chattisgarh_winners <- filter(chattisgarh, position ==1, poll_no==0) #Filter out the winners # Just take poll 0
# chattisgarh_winners$sex <- revalue(chattisgarh_winners$sex, c("M"="0", "F"="1"))
# chattisgarh_winners$st_code <- rep("CHATTIS", nrow(chattisgarh_winners))
# chattisgarh_winners$state_year <- paste(chattisgarh_winners$st_code,chattisgarh_winners$year)
# chattisgarh_winners <-  chattisgarh_winners %>% select(1,2,4, 6,7,9,10,11,12,13,14,15,16,17,18,21,22,23,24,25, 27,28)
# 
# 
# #Creating reservation dummies
# chattisgarh_winners$reservation <- NA
# chattisgarh_winners$reservation[chattisgarh_winners$year > 2005] <- 1
# chattisgarh_winners$reservation[is.na(chattisgarh_winners$reservation)] <- 0
# 
# #Creating 1/2 dummy
# chattisgarh_winners$fiftypercent <- NA
# chattisgarh_winners$fiftypercent[chattisgarh_winners$year > 2005] <- 1/3
# chattisgarh_winners$fiftypercent[chattisgarh_winners$year > 2008] <- 1/2
# chattisgarh_winners$fiftypercent[is.na(chattisgarh_winners$fiftypercent)] <- 0

#merge Datasets
all_india <- rbind(andhra_winners,assam_winners,bihar_winners,gujarat_winners,haryana_winners, himachal_winners,
                   jandk_winners,karnataka_winners,kerala_winners,madhya_pradesh_winners,maharashtra_winners, manipur_winners,
                   meghalaya_winners,nagaland_winners, odisha_winners, punjab_winners,rajasthan_winners,sikkim_winners,
                   tamil_nadu_winners, tripura_winners, uttar_pradesh_winners,west_bengal_winners,
                   arunachal_winners, delhi_winners, goa_winners, mizoram_winners, puducherry_winners)

write_dta(all_india,"/Users/varun/Library/Mobile Documents/com~apple~CloudDocs/Downloads/qjps_final_replication_home/all_india.dta")


# BBS data ----------------------------------------------------------------

bbs <- read_stata("BBS-Data.dta")

bbs$st_code1<- mapvalues(bbs$scode3866, from = 1:22,
                         to = c("ANP","ASS","BIH", "GUJ", "HAR", "HIP",
                                "JAK", "KAR", "KER", "MAP", "MAH", "MAN",
                                "MEG", "NAG", "ORI", "PUN", "RAJ", "SIK",
                                "TAM", "TRI", "UTP","WEB"))

bbs$st_code1[bbs$scode3866 ==24] <- "ARP"
bbs$st_code1[bbs$scode3866 ==27] <- "DEl"
bbs$st_code1[bbs$scode3866 ==28] <- "GOA"
bbs$st_code1[bbs$scode3866 ==30] <- "MIZ"
bbs$st_code1[bbs$scode3866 ==31] <- "PUD"




bbs$state_year <- paste(bbs$st_code1,bbs$year)

final_data <- left_join(all_india, bbs, by = "state_year")

colnames(final_data)[which(names(final_data) == "year.x")] <- "year_1"
colnames(final_data)[which(names(final_data) == "year.y")] <- "year_2" 
colnames(final_data)[which(names(final_data) == "st_code.x")] <- "st_code_1"
colnames(final_data)[which(names(final_data) == "st_code.y")] <- "st_code_2"

write_dta(final_data,"/Users/varun/Library/Mobile Documents/com~apple~CloudDocs/Downloads/qjps_final_replication_home/final_data.dta")
write_csv(final_data,"/Users/varun/Library/Mobile Documents/com~apple~CloudDocs/Downloads/qjps_final_replication_home/final_data.csv")





