rm(list=ls())

rm(list=ls())

# This section of the code installs all the missing packages --------------
list.of.packages <- c("haven", "stargazer", "readstata13","readr"
                      ,"plyr","dplyr","ggplot2","gghighlight","plm"
                      ,"lmtest","multiwayvcov","broom","here")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)

library(here)
library(haven)
library(stargazer)
library(readstata13)
library(readr)
library(plyr)
library(dplyr)
library(ggplot2)
library(gghighlight)
library(plm)
library(lmtest)
library(multiwayvcov)
library(broom)



# Data Cleaning -----------------------------------------------------------

final_data <- read_dta("final_data.dta")

final_data <- transform(final_data, sex = as.numeric(sex))

final_data$assembly_no <- as.integer(final_data$assembly_no)
final_data <- final_data %>% dplyr::select(-st_code1,-st_code_2,-year_2,-southIndia,-time)

# Create proportion of females - DV ---------------------------------------

final_data<- final_data %>%
    dplyr:: group_by(state_year) %>%
    dplyr:: mutate(sex_prop = mean(sex, na.rm=T))

# Create Final Panel Data -------------------------------------------------

final_panel<- unique(final_data[, c("sex_prop", "reservation", "i_flit", "lnsdp", 
                             "legIdeology", "i_sexratio", "i_urban", "ph3_sh", "otrev_pop",
                             "ontrev_pop", "lnphe3", "st_code_1", "year_1", "state_name", 
                             "pcph3_r2","lnSocExp3", "imr", "nSeats", "assembly_no",
                             "fiftypercent")])

# final_panel <- final_panel %>% filter(year_1 >1983)  #To only cover the panel for which I have control variables! 

# Exposure Measure --------------------------------------------------------

final_panel$year_1 <- as.integer(final_panel$year_1)
final_panel$difference <- NA
final_panel <- final_panel %>%  arrange(state_name, year_1)
final_panel <- final_panel %>%
     group_by(state_name) %>% 
     mutate(year_1lead = dplyr::lag(year_1))

final_panel$difference <- final_panel$year_1-final_panel$year_1lead #Create differences between years to later obtain exposure_cumsum_years

final_panel <- final_panel%>% 
     group_by(state_name) %>% mutate(exposure = sum(reservation)-1) #EXPOSURE Gives sum total of reservation dummy(at state-election-year level) -1 to only ecount exposed years
final_panel$exposure[final_panel$reservation==0] <- 0 #Have made exposure redundant with the next two lines!


final_panel <- final_panel %>% group_by(state_name)
final_panel <- final_panel %>% 
     mutate(exposure_years = ifelse(reservation==1, max(year_1[reservation==1]) - min(year_1[reservation==1]), 0))

#EXPOSURE_YEARS Gives total exposure in years. 

final_panel <- final_panel %>% 
     arrange(state_name, year_1) %>% mutate(exposure_cumsum = cumsum(reservation))#EXPOSURE_CUMSUM Gives cumulative exposure by state_election year

final_panel$exposure_cumsum[final_panel$reservation == 0] <- 0
final_panel$exposure_cumsum <- ((final_panel$exposure_cumsum)-1)

#Bihar 2005 fix: Automate this!!
final_panel$exposure_cumsum[final_panel$year_1==2005 & final_panel$assembly_no==13] <- 0
final_panel$exposure_cumsum[final_panel$year_1==2005 & final_panel$assembly_no==14] <- 0
final_panel$exposure_cumsum[final_panel$year_1==2010 & final_panel$assembly_no==15] <- 1
final_panel$exposure_cumsum[final_panel$year_1==2015 & final_panel$assembly_no==16] <- 2


final_panel$exposure_cumsum[final_panel$exposure_cumsum ==-1] <- 0

final_panel <- final_panel %>% arrange(state_name,assembly_no) 
final_panel$difference <- ifelse(final_panel$exposure_cumsum!=0 & final_panel$reservation ==1, final_panel$difference,0)  #To identify those years which had exposure
 
final_panel <- final_panel %>%   
     mutate(exposure_cumsum_years = cumsum(difference))

# temp <- final_panel %>% select(state_name, year_1,assembly_no,reservation, exposure_cumsum, difference,exposure_cumsum_years, twentyfive_years)



#EXPOSURE_CUMSUM_YEARS Gives cumulative exposure by state_election year and multiplies by 5 -5 for the same reason as above

#Exposure Dummies

# 1 to 3 years

final_panel <- final_panel %>% mutate(three_years = ifelse(dplyr::between(exposure_cumsum_years, 1, 3),1,0))

# 3 to 5 years
final_panel <- final_panel %>% mutate(three_to_five_years = ifelse(dplyr::between(exposure_cumsum_years, 3, 5),1,0))

# 5 to 7 years
final_panel <- final_panel %>% mutate(five_to_seven_years = ifelse(dplyr::between(exposure_cumsum_years, 5, 7),1,0))

#7 to 10 years
final_panel <- final_panel %>% mutate(seven_to_ten_years = ifelse(dplyr::between(exposure_cumsum_years, 7, 10),1,0))

#10 to 13 years

final_panel <- final_panel %>% mutate(ten_to_thirteen_years = ifelse(dplyr::between(exposure_cumsum_years, 10, 13),1,0))

#13 to 15 years
final_panel <- final_panel %>% mutate(thirteen_to_fifteen_years = ifelse(dplyr::between(exposure_cumsum_years, 13, 15),1,0))

#15 to 18 year
final_panel <- final_panel %>% mutate(fifteen_to_eighteen_years = ifelse(dplyr::between(exposure_cumsum_years, 15, 18),1,0))

#18 to 20 year
final_panel <- final_panel %>% mutate(eighteen_to_twenty_years = ifelse(dplyr::between(exposure_cumsum_years, 18, 20),1,0))

#20 to 25 year

final_panel <- final_panel %>% mutate(twenty_to_twentyfive_years = ifelse(dplyr::between(exposure_cumsum_years, 20, 25),1,0))

#greater than 3

final_panel <- final_panel %>% mutate(than_three = ifelse(exposure_cumsum_years >3 ,1,0))


#1 to 5 year exposure: five_years


final_panel <- final_panel %>% mutate(five_years = ifelse(dplyr::between(exposure_cumsum_years, 1, 5),1,0))

#6 to 10 year exposure: ten_years
final_panel <- final_panel %>% mutate(ten_years = ifelse(dplyr::between(exposure_cumsum_years, 6, 10),1,0))

#11 to 15 year exposure: fifteen_years
final_panel <- final_panel %>% mutate(fifteen_years = ifelse(dplyr::between(exposure_cumsum_years, 11, 15),1,0))

#16 to 20 year exposure: fifteen_years
final_panel <- final_panel %>% mutate(twenty_years = ifelse(dplyr::between(exposure_cumsum_years, 16, 20),1,0))

#21 to 25 year exposure: fifteen_years
final_panel <- final_panel %>% mutate(twentyfive_years = ifelse(dplyr::between(exposure_cumsum_years, 21, 25),1,0))

#greater than 5 years exposure: 
final_panel <- final_panel %>% mutate(than_five = ifelse(exposure_cumsum_years >5 ,1,0))
#greater than 10 years exposure: 
final_panel <- final_panel %>% mutate(than_ten = ifelse(exposure_cumsum_years >10 ,1,0))
#greater than 15 years exposure: 
final_panel <- final_panel %>% mutate(than_fifteen = ifelse(exposure_cumsum_years >15 ,1,0))




#1 to five years
final_panel <- final_panel %>% mutate(to_five = ifelse(dplyr::between(exposure_cumsum_years, 1, 5),1,0))
#1 to ten years
final_panel <- final_panel %>% mutate(to_ten = ifelse(dplyr::between(exposure_cumsum_years, 1, 10),1,0))
#1 to fifteen years
final_panel <- final_panel %>% mutate(to_fifteen = ifelse(dplyr::between(exposure_cumsum_years, 1, 15),1,0))

#1 to twenty years
final_panel <- final_panel %>% mutate(to_twenty = ifelse(dplyr::between(exposure_cumsum_years, 1, 20),1,0))
#1 to twentyfive years
final_panel <- final_panel %>% mutate(to_twentyfive = ifelse(dplyr::between(exposure_cumsum_years, 1, 25),1,0))



# line 181 below (commented) saves the dataset as a .dta file, i have named it final_panel which will be used for the main analysis



write_dta(final_panel,"/Users/varun/Library/Mobile Documents/com~apple~CloudDocs/Downloads/qjps_final_replication_home/final_panel.dta")

