rm(list=ls())
# setwd("/Users/varun/Dropbox/PhD/2YP/Data/data_analysis")
list.of.packages <- c("haven", "stargazer", "readstata13","readr"
                      ,"plyr","dplyr","ggplot2","gghighlight","plm", "lmtest","multiwaycov","broom","tidyr",
                      "interplot", "expss","xtable","ggthemes")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)

library(haven)
library(stargazer)
library(readstata13)
library(readr)
library(plyr)
library(dplyr)
library(ggplot2)
library(gghighlight)
library(plm)
library(lmtest)
library(multiwayvcov)
library(expss)
library(broom)
library(tidyr)
library(expss)# library(interplot)

final_panel <- read_dta("final_panel.dta")

# To get the year of first reservation in geom_vline ----------------------

first_reservation_year <- final_panel %>% 
     # Convert variable to factor, so we can use complete later. We do this within
     # group_by, because we want to operate by level of variable
     group_by(state_name=factor(state_name)) %>% 
     # Remove all rows of variable if there aren't any rows with values==0
     filter(any(reservation==0)) %>% 
     # Remove all rows with values != 0
     filter(reservation != 0) %>% 
     # Keep the first row of each variable, after sorting by Date
     # This gives us the first non-zero row
     arrange(year_1) %>% 
     slice(1) %>% 
     # Use complete to bring back a row for any level of variable that
     # didn't start with any rows with values==0
     ungroup() %>% 
     complete(state_name)




# Figure A. 2 Proportion Plot ---------------------------------------------------------

ggplot(data=final_panel, aes(x=year_1, y=sex_prop, group = state_name)) +
     geom_line() +
     geom_point( size=1, shape=20, fill="white") +
     geom_vline(data = first_reservation_year, aes(xintercept=year_1-1), color="red", 
                linetype="dashed",size=0.4) +  
     scale_linetype_discrete(name = "Year of Reservation") +
     facet_wrap( "state_name",scales='free_x')+xlab("Election Year") + 
     ylab("Proportion of Women in state Assembly")+ theme_bw()+
     theme(panel.border = element_blank(), panel.grid.major = element_blank(), 
           strip.background = element_blank(),panel.grid.minor = element_blank(),axis.title=element_text(size=16,face="bold"))


