rm(list=ls())
# setwd("/Users/varun/Dropbox/PhD/2YP/Data/data_analysis/")
list.of.packages <- c("haven", "stargazer", "readstata13","readr"
                      ,"plyr","dplyr","ggplot2","gghighlight","plm", "lmtest","multiwaycov","broom","tidyr",
                      "expss","magrittr")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)
  
library(haven)
library(stargazer)
library(readstata13)
library(readr)
library(plyr)
library(dplyr)
library(ggplot2)
library(gghighlight)
library(plm)
library(lmtest)
library(multiwayvcov)
library(broom)
library(expss)
final_data <- read_dta("final_data.dta")
final_data <- transform(final_data, sex = as.numeric(sex))

final_data$assembly_no <- as.integer(final_data$assembly_no)
final_data <- final_data %>% dplyr::select(-st_code1,-st_code_2,-year_2,-southIndia,-time)

# Robust Standard Errors --------------------------------------------------

robustse.f <- function(model, cluster, df_correction) {
     ## Huber-White heteroskedasticity-robust standard error calculation and table generation code for lm and glm models in R.
     ##Written by Joshua Gubler ~  http://joshuagubler.com.  Note that the second half of this function is just a wrapper for the excellent "multiwaycov" package here: https://cran.r-project.org/web/packages/multiwayvcov/multiwayvcov.pdf .  Love the authors of that package...
     ##Last updated: 3 July 2017  
     
     #model = the model you estimated, now calculated with robust standard errors
     #cluster = the name of the variable on which you will cluster. Put a tilda in front of it (e.g. ~ state).  If you don't put in a cluster, you will simply get huber-white robust errors.
     #df_correction: If you do not want the number of levels in your cluster variable to count against your degrees of freedom (like the xt- options in Stata), then type "F".  Otherwise, type "T" and these levels will be counted against your degrees of freedom
     
     require(sandwich)
     require(lmtest)
     require(multiwayvcov)
     if(missing(cluster)) {
          name <- deparse(substitute(model))
          modelname <- paste(name,"rob",sep=".")
          model$se <- coeftest(model, vcov=vcovHC(model,"HC1"))[,2]
          model$vcovHC <- vcovHC(model,"HC1")
          assign(modelname,model,envir = .GlobalEnv)
          coeftest(model, vcov=vcovHC(model,"HC1"))
     } else {
          name <- deparse(substitute(model))
          modelname <- paste(name,"rob",sep=".")
          vcovCL <- cluster.vcov(model, cluster, df_correction = df_correction)
          model$vcovCL <- vcovCL
          modelname <- paste(name,"clustrob",sep=".")
          model$se <- coeftest(model, vcovCL)[,2]
          assign(modelname,model,envir = .GlobalEnv)
          coeftest(model, vcovCL)
     }
}


# Create proportion of females - DV ---------------------------------------

final_data<- final_data %>%
    dplyr:: group_by(state_year) %>%
     mutate(sex_prop = mean(sex, na.rm=T))
final_data <- final_data %>% filter(!is.na(sex_prop))


#Create Cadreparty dummy
final_data$cadreparty <- NA
final_data$cadreparty[final_data$party == "CPI"|final_data$party == "CPM"] <- 1
final_data$cadreparty[is.na(final_data$cadreparty)] <- 0


final_data$bjp <- NA
final_data$bjp[final_data$party == "BJP"] <- 1
final_data$bjp[is.na(final_data$bjp)] <- 0

final_data$inc <- NA
final_data$inc[final_data$party == "INC"] <- 1
final_data$inc[is.na(final_data$inc)] <- 0

# Proportion of Cadre Party Winners ---------------------------------------
final_data<- final_data %>%
     dplyr::group_by(state_year) %>%
     dplyr::mutate(cadre_prop = mean(cadreparty, na.rm=T))

final_data<- final_data %>%
  dplyr::group_by(state_year) %>%
  dplyr::mutate(bjp_prop = mean(bjp, na.rm=T))

final_data<- final_data %>%
  dplyr::group_by(state_year) %>%
  dplyr::mutate(inc_prop = mean(inc, na.rm=T))

# Create Final Panel Data -------------------------------------------------
final_panel<- unique(final_data[, c("sex_prop", "reservation", "i_flit", "lnsdp", 
                                    "legIdeology", "i_sexratio", "i_urban", "ph3_sh", "otrev_pop",
                                    "ontrev_pop", "lnphe3", "st_code_1", "year_1", "state_name", 
                                    "pcph3_r2","lnSocExp3", "imr", "nSeats", "assembly_no",
                                    "fiftypercent","cadre_prop","bjp_prop","inc_prop")])


# ONly retain major states
final_panel_major_states <- final_panel %>% filter(state_name!="Himachal_Pradesh"&
                                                        state_name!="Jammu_&_Kashmir"&
                                                        state_name!="Manipur"&state_name!="Meghalaya"&
                                                        state_name!="Nagaland"& state_name!="Sikkim"&
                                                        state_name!="Tripura"& state_name!="Arunachal_Pradesh"&
                                                        state_name!="Goa"&state_name!="Mizoram"&
                                                        state_name!="Puducherry"&state_name!="Delhi")

# Merge Proportions for Candidate histories
final_panel_major_states$concatenate <- paste(final_panel_major_states$state_name,final_panel_major_states$assembly_no)
cand_hist <- read_csv("proportions_assembly_wise.csv")

library("magrittr")
names(cand_hist) %<>% tolower
joined_df <- left_join(final_panel_major_states,cand_hist, by = "concatenate")

joined_df$cadre_fifty <- NA
joined_df$cadre_fifty[joined_df$cadre_prop > 0.499] <- 1
joined_df$cadre_fifty[is.na(joined_df$cadre_fifty)] <- 0

joined_df$bjp_fifty <- NA
joined_df$bjp_fifty[joined_df$bjp_prop > 0.499] <- 1
joined_df$bjp_fifty[is.na(joined_df$bjp_fifty)] <- 0

joined_df$inc_fifty <- NA
joined_df$inc_fifty[joined_df$inc_prop > 0.499] <- 1
joined_df$inc_fifty[is.na(joined_df$inc_fifty)] <- 0


joined_df$lagged_cadre_fifty <- dplyr::lag(joined_df$cadre_fifty,1)
joined_df$lagged_bjp_fifty <- dplyr::lag(joined_df$bjp_fifty,1)
joined_df$lagged_inc_fifty <- dplyr::lag(joined_df$inc_fifty,1)
joined_df$lagged_cadreparty <- dplyr::lag(joined_df$cadre_prop,1)
joined_df$lagged_cadreparty <- dplyr::lag(joined_df$cadre_prop,1)
joined_df$lagged_bjp_prop <- dplyr::lag(joined_df$bjp_prop,1)
joined_df$lagged_inc_prop <- dplyr::lag(joined_df$inc_prop,1)




# Proportion of Parties ---------------------------------------------------

m1 <- lm(prop_pure_local ~  lagged_cadreparty + sex_prop +factor(state_name) + factor(year_1)  , data = joined_df)
summary(m1) 

m2 <- lm(prop_pure_local ~  lagged_bjp_prop +sex_prop+factor(state_name) + factor(year_1) + sex_prop , data = joined_df)
summary(m2)

m3 <- lm(prop_pure_local ~  lagged_inc_prop+sex_prop +factor(state_name) + factor(year_1)+ sex_prop, data = joined_df)
summary(m3)


# Table 6 Panel A ---------------------------------------------------------


stargazer(m1, m2,m3 ,omit = "factor", 
          digits=3, 
          title = "Parties  and Type of Candidates",
          t.auto = TRUE,
         type = 'text',
          covariate.labels = c("Lagged Proportion of Cadre Based Party (CPI and CPI(M)) Legislators","Lagged Proportion of BJP Legislators", "Proportion of INC Legislators",
                               "Proportion of Female Legislators"),
          dep.var.labels   = "Proportion of purely local-level female legislators",
          add.lines = list(c("Fixed effects: State and Time", "Yes", "Yes", "Yes")),
          notes=c("Robust standard errors in parentheses"))

m4 <- lm(prop_pure_dynast ~  lagged_cadreparty +sex_prop+factor(state_name) + factor(year_1)  , data = joined_df)
summary(m4) 

m5 <- lm(prop_pure_dynast ~  lagged_bjp_prop +sex_prop+factor(state_name) + factor(year_1) + sex_prop , data = joined_df)
summary(m5)

m6 <- lm(prop_pure_dynast ~  lagged_inc_prop +sex_prop+factor(state_name) + factor(year_1)+ sex_prop, data = joined_df)
summary(m6)

# Table 6 Panel B ---------------------------------------------------------


stargazer(m4, m5,m6 ,omit = "factor", 
          digits=3, 
          title = "Parties  and Type of Candidates",
          type= "text",
          t.auto = TRUE,
          covariate.labels = c("Proportion of Cadre Based Parties (CPI and CPI(M))","Proportion of BJP", "Proportion of INC",
                               "proportion of Female egislators"),
          dep.var.labels   = "Proportion of purely dynastic female legislators",
          add.lines = list(c("Fixed effects: State and Time", "Yes", "Yes", "Yes")),
          notes=c("Robust standard errors in parentheses"))


# Cadre Party Share >50% ---------------------------------------

m7 <- lm(prop_pure_local ~  lagged_cadre_fifty +sex_prop +factor(state_name) + factor(year_1)  , data = joined_df)
summary(m1)

m8 <- lm(prop_pure_local ~  lagged_bjp_fifty +sex_prop +factor(state_name) + factor(year_1) , data = joined_df)
summary(m2)

m9 <- lm(prop_pure_local ~  lagged_inc_fifty +sex_prop +factor(state_name) + factor(year_1), data = joined_df)
summary(m3)


# Table A.17, Panel A -----------------------------------------------------

stargazer(m7, m8,m9 ,omit = "factor", 
          digits=3, 
          title = "Party Structure and Type of Candidates",
          t.auto = TRUE,
          type = "text",
          covariate.labels = c("Lagged CPI and CPI(M) seat share >50%","Lagged BJP Seat Share > 50%", "Lagged INC Seat Share >50%",
                               "proportion of Female egislators"),
          dep.var.labels   = "Proportion of purely local-level female legislators",
          add.lines = list(c("Fixed effects: State and Time", "Yes", "Yes", "Yes"),
                           c("State Level Controls?", "Yes", "Yes", "Yes")),
          notes=c("Robust standard errors in parentheses"))
          


m10 <- lm(prop_pure_dynast ~  lagged_cadre_fifty + sex_prop + factor(state_name) + factor(year_1), data = joined_df)
m11 <- lm(prop_pure_dynast ~  lagged_bjp_fifty + sex_prop + factor(state_name) + factor(year_1), data = joined_df)
m12 <- lm(prop_pure_dynast ~  lagged_inc_fifty + sex_prop  + factor(state_name) + factor(year_1), data = joined_df)

# Table A.17, Panel B ----------------------------------------------------
stargazer(m10, m11,m12 ,omit = "factor", 
          digits=3, 
          title = "Party Structure and Type of Candidates",
          t.auto = TRUE,
          type = "text",
          covariate.labels = c("Lagged CPI and CPI(M) seat share >50%","Lagged BJP Seat Share > 50%", "Lagged INC Seat Share >50%",
                               "proportion of Female egislators"),
          dep.var.labels   = "Proportion of purely dynastic female legislators",
          add.lines = list(c("Fixed effects: State and Time", "Yes", "Yes", "Yes"),
                           c("State Level Controls?", "Yes", "Yes", "Yes")),
          notes=c("Robust standard errors in parentheses"))



# Figure 2 ----------------------------------------------------------------


mobility_plot_df <- joined_df %>% filter(reservation>0) #To restrict to post-quota time

mobility_plot <- ggplot(mobility_plot_df, aes(x=year_1)) + 
     geom_line(aes(y=prop_pure_local, col="prop_pure_local", linetype="dotdash")) + 
     geom_line(aes(y=prop_pure_dynast, col="prop_pure_dynast", linetype="solid")) + 
     labs(title="Proportions Loca-Level and Dynatic Female Legislators Among Female Legislators across 15 Major Indian States", 
          #subtitle="Drawn From Wide Data format", 
          caption="") +  # title and caption
     #scale_x_date(labels = lbls, breaks = brks) +  # change to monthly ticks and labels
     facet_wrap( "state_name",scales='free_x')+xlab("Election Year") + ylab("Proportion") +
     theme_bw()+
     scale_color_manual(labels = c("Proportion of Purely Dynastic Winners","Proportion of Purely local Winners"),name="", 
                        values = c("prop_pure_local"="Black", "prop_pure_dynast"="Black")) +  # line color
     theme(panel.border = element_blank(), panel.grid.major = element_blank(), panel.spacing = unit(2, "lines"),
           strip.background = element_blank(),panel.grid.minor = element_blank(),axis.title=element_text(size=16,face="bold"),
           legend.position = "none",
           panel.background = element_rect(fill = "#FAFAFA", colour = NA),
           plot.background = element_rect(fill = "#FAFAFA",colour = NA))

mobility_plot

