rm(list=ls())
list.of.packages <- c("haven", "stargazer", "readstata13","readr"
                      ,"plyr","dplyr","ggplot2","gghighlight","plm", "lmtest","multiwaycov","broom","tidyr",
                      "interplot", "expss","scales","gridExtra","grid")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)


remotes::install_github("sammo3182/interplot")
library(haven)
library(stargazer)
library(readstata13)
library(readr)
library(plyr)
library(dplyr)
library(ggplot2)
library(gghighlight)
library(plm)
library(lmtest)
library(multiwayvcov)
library(broom)
library(tidyr)
library(expss)

library(interplot)

# Robust Standard Errors --------------------------------------------------

robustse.f <- function(model, cluster, df_correction) {
     ## Huber-White heteroskedasticity-robust standard error calculation and table generation code for lm and glm models in R.
     ##Written by Joshua Gubler ~  http://joshuagubler.com.  Note that the second half of this function is just a wrapper for the excellent "multiwaycov" package here: https://cran.r-project.org/web/packages/multiwayvcov/multiwayvcov.pdf .  Love the authors of that package...
     ##Last updated: 3 July 2017  
     
     #model = the model you estimated, now calculated with robust standard errors
     #cluster = the name of the variable on which you will cluster. Put a tilda in front of it (e.g. ~ state).  If you don't put in a cluster, you will simply get huber-white robust errors.
     #df_correction: If you do not want the number of levels in your cluster variable to count against your degrees of freedom (like the xt- options in Stata), then type "F".  Otherwise, type "T" and these levels will be counted against your degrees of freedom
     
     require(sandwich)
     require(lmtest)
     require(multiwayvcov)
     if(missing(cluster)) {
          name <- deparse(substitute(model))
          modelname <- paste(name,"rob",sep=".")
          model$se <- coeftest(model, vcov=vcovHC(model,"HC1"))[,2]
          model$vcovHC <- vcovHC(model,"HC1")
          assign(modelname,model,envir = .GlobalEnv)
          coeftest(model, vcov=vcovHC(model,"HC1"))
     } else {
          name <- deparse(substitute(model))
          modelname <- paste(name,"rob",sep=".")
          vcovCL <- cluster.vcov(model, cluster, df_correction = df_correction)
          model$vcovCL <- vcovCL
          modelname <- paste(name,"clustrob",sep=".")
          model$se <- coeftest(model, vcovCL)[,2]
          assign(modelname,model,envir = .GlobalEnv)
          coeftest(model, vcovCL)
     }
}


final_panel <- read_dta("final_panel.dta")

gps <- read_csv("GPs.csv")

final_panel_gps <- full_join(final_panel,gps)

trimmed_data <- final_panel_gps %>% 
     dplyr::select(sex_prop, reservation, state_name, reservation, total_elected_reps, 
                   total_gps, total_women_reps,year_1)

trimmed_data <- trimmed_data %>% 
     dplyr::filter(state_name!="Chhattisgarh"&
                       state_name!="Jharkhand"&
                        state_name!="Uttarakhand"&
                        state_name!="Orissa"&
                        state_name!="Delhi")


trimmed_data <- trimmed_data %>% dplyr::mutate(log_reps=log(total_elected_reps))
trimmed_data <- trimmed_data %>% dplyr::mutate(log_gps=log(total_gps))


m1 <- lm(sex_prop ~ reservation * log_reps, data=trimmed_data)

m2 <- lm(sex_prop ~ reservation * log_gps, data=trimmed_data)

m3 <- lm(sex_prop ~ reservation * total_women_reps,data=final_panel_gps)
library(interplot)
library(scales)


# Figure 1 Here -----------------------------------------------------------

#Panel 1
 interplot(m = m1,  var1 = "reservation",var2 = "log_reps", hist=TRUE)+
     geom_hline(aes(yintercept = 0), linetype = "dashed", color="red", size=0.4) +
     #geom_rug(mapping=aes(x=total_women_reps), data=final_panel_gps)+
     xlab("Total Number of Elected Representatives") +
     ylab("Prop. of Women in Legislatures") +
     theme_bw() +
     theme(text = element_text(size=16)) +
     ggtitle("") +
     theme(plot.title = element_text(face="bold")) +
     scale_x_continuous(labels = comma) + geom_jitter()
     

#Figure 1 second panel
interplot(m = m2, var1 = "reservation", var2 = "log_gps",hist = T)+
        geom_hline(aes(yintercept = 0), linetype = "dashed", color="red",size=0.4)+
       #geom_rug(mapping=aes(x=total_gps), data=final_panel_gps)+
        xlab("Total Number of GPs") +
        ylab("Prop. of Women in Legislatures") +
        theme_bw() +
        theme(text = element_text(size=16)) +
       ggtitle("") +
            theme(plot.title = element_text(face="bold")) +
            scale_x_continuous(labels = comma) + geom_jitter()



